Module event
xscan_
lib
0.1.1
Module event
Module Items
Structs
In xscan_
lib::
log
xscan_lib
::
log
Module
event
Events represent single points in time during the execution of a program.
Structs

Event
Event
s represent single points in time where something occurred during the execution of a program.